@@ -15,6 +15,10 @@ SEXP R_H5Pcopy(SEXP R_plist_id);
 SEXP R_H5Pcopy_prop(SEXP R_dst_id, SEXP R_src_id, SEXP R_name);
 /* H5_DLL hid_t H5Pcreate(hid_t cls_id); */
 SEXP R_H5Pcreate(SEXP R_cls_id);
+/* H5_DLL hid_t H5Pdecode(const void *buf); */
+SEXP R_H5Pdecode(SEXP R_buf);
+/* H5_DLL herr_t H5Pencode(hid_t plist_id, void *buf, size_t *nalloc); */
+SEXP R_H5Pencode(SEXP R_plist_id, SEXP R_buf, SEXP R_nalloc, SEXP _dupl_buf);
 /* H5_DLL htri_t H5Pequal(hid_t id1, hid_t id2); */
 SEXP R_H5Pequal(SEXP R_id1, SEXP R_id2);
 /* H5_DLL htri_t H5Pexist(hid_t plist_id, const char *name); */
@@ -43,6 +47,8 @@ SEXP R_H5Pget_char_encoding(SEXP R_plist_id, SEXP R_encoding);
 SEXP R_H5Pget_chunk(SEXP R_plist_id, SEXP R_max_ndims, SEXP R_dim);
 /* H5_DLL herr_t H5Pget_chunk_cache(hid_t dapl_id, size_t *rdcc_nslots, size_t *rdcc_nbytes, double *rdcc_w0); */
 SEXP R_H5Pget_chunk_cache(SEXP R_dapl_id, SEXP R_rdcc_nslots, SEXP R_rdcc_nbytes, SEXP R_rdcc_w0);
+/* H5_DLL herr_t H5Pget_chunk_opts(hid_t plist_id, unsigned *opts); */
+SEXP R_H5Pget_chunk_opts(SEXP R_plist_id, SEXP R_opts);
 /* H5_DLL hid_t H5Pget_class(hid_t plist_id); */
 SEXP R_H5Pget_class(SEXP R_plist_id);
 /* H5_DLL char *H5Pget_class_name(hid_t pclass_id); */
@@ -51,6 +57,8 @@ SEXP R_H5Pget_class_name(SEXP R_pclass_id);
 SEXP R_H5Pget_class_parent(SEXP R_pclass_id);
 /* H5_DLL herr_t H5Pget_copy_object(hid_t plist_id, unsigned *crt_intmd ); */
 SEXP R_H5Pget_copy_object(SEXP R_plist_id, SEXP R_crt_intmd);
+/* H5_DLL herr_t H5Pget_core_write_tracking(hid_t fapl_id, hbool_t *is_enabled, size_t *page_size); */
+SEXP R_H5Pget_core_write_tracking(SEXP R_fapl_id, SEXP R_is_enabled, SEXP R_page_size);
 /* H5_DLL herr_t H5Pget_create_intermediate_group(hid_t plist_id, unsigned *crt_intmd ); */
 SEXP R_H5Pget_create_intermediate_group(SEXP R_plist_id, SEXP R_crt_intmd);
 /* H5_DLL ssize_t H5Pget_data_transform(hid_t plist_id, char* expression , size_t size); */
@@ -59,6 +67,8 @@ SEXP R_H5Pget_data_transform(SEXP R_plist_id, SEXP R_expression, SEXP R_size);
 SEXP R_H5Pget_driver(SEXP R_plist_id);
 /* H5_DLL H5Z_EDC_t H5Pget_edc_check(hid_t plist_id); */
 SEXP R_H5Pget_edc_check(SEXP R_plist_id);
+/* H5_DLL ssize_t H5Pget_efile_prefix(hid_t dapl_id, char* prefix , size_t size); */
+SEXP R_H5Pget_efile_prefix(SEXP R_dapl_id, SEXP R_prefix, SEXP R_size);
 /* H5_DLL herr_t H5Pget_elink_acc_flags(hid_t lapl_id, unsigned *flags); */
 SEXP R_H5Pget_elink_acc_flags(SEXP R_lapl_id, SEXP R_flags);
 /* H5_DLL hid_t H5Pget_elink_fapl(hid_t lapl_id); */
@@ -77,6 +87,8 @@ SEXP R_H5Pget_external_count(SEXP R_plist_id);
 SEXP R_H5Pget_family_offset(SEXP R_fapl_id, SEXP R_offset);
 /* H5_DLL herr_t H5Pget_fclose_degree(hid_t fapl_id, H5F_close_degree_t *degree); */
 SEXP R_H5Pget_fclose_degree(SEXP R_fapl_id, SEXP R_degree);
+/* H5_DLL herr_t H5Pget_file_space(hid_t plist_id, H5F_file_space_type_t *strategy, hsize_t *threshold); */
+SEXP R_H5Pget_file_space(SEXP R_plist_id, SEXP R_strategy, SEXP R_threshold);
 /* H5_DLL herr_t H5Pget_fill_time(hid_t plist_id, H5D_fill_time_t *fill_time); */
 SEXP R_H5Pget_fill_time(SEXP R_plist_id, SEXP R_fill_time);
 /* H5_DLL herr_t H5Pget_fill_value(hid_t plist_id, hid_t type_id, void *value); */
@@ -103,8 +115,12 @@ SEXP R_H5Pget_link_phase_change(SEXP R_plist_id, SEXP R_max_compact, SEXP R_min_
 SEXP R_H5Pget_local_heap_size_hint(SEXP R_plist_id, SEXP R_size_hint);
 /* H5_DLL herr_t H5Pget_mdc_config(hid_t plist_id, H5AC_cache_config_t * config_ptr);  */
 SEXP R_H5Pget_mdc_config (SEXP R_plist_id, SEXP R_config_ptr);
+/* H5_DLL herr_t H5Pget_mdc_log_options(hid_t plist_id, hbool_t *is_enabled, char *location, size_t *location_size, hbool_t *start_on_access); */
+SEXP R_H5Pget_mdc_log_options(SEXP R_plist_id, SEXP R_is_enabled, SEXP R_location, SEXP R_location_size, SEXP R_start_on_access);
 /* H5_DLL herr_t H5Pget_meta_block_size(hid_t fapl_id, hsize_t *size); */
 SEXP R_H5Pget_meta_block_size(SEXP R_fapl_id, SEXP R_size);
+/* H5_DLL herr_t H5Pget_metadata_read_attempts(hid_t plist_id, unsigned *attempts); */
+SEXP R_H5Pget_metadata_read_attempts(SEXP R_plist_id, SEXP R_attempts);
 /* H5_DLL herr_t H5Pget_multi_type(hid_t fapl_id, H5FD_mem_t *type); */
 SEXP R_H5Pget_multi_type(SEXP R_fapl_id, SEXP R_type);
 /* H5_DLL int H5Pget_nfilters(hid_t plist_id); */
@@ -137,6 +153,20 @@ SEXP R_H5Pget_sym_k(SEXP R_plist_id, SEXP R_ik, SEXP R_lk);
 SEXP R_H5Pget_userblock(SEXP R_plist_id, SEXP R_size);
 /* H5_DLL herr_t H5Pget_version(hid_t plist_id, unsigned *boot, unsigned *freelist, unsigned *stab, unsigned *shhdr); */
 SEXP R_H5Pget_version(SEXP R_plist_id, SEXP R_boot, SEXP R_freelist, SEXP R_stab, SEXP R_shhdr);
+/* H5_DLL herr_t H5Pget_virtual_count(hid_t dcpl_id, size_t *count); */
+SEXP R_H5Pget_virtual_count(SEXP R_dcpl_id, SEXP R_count);
+/* H5_DLL ssize_t H5Pget_virtual_dsetname(hid_t dcpl_id, size_t index, char *name, size_t size); */
+SEXP R_H5Pget_virtual_dsetname(SEXP R_dcpl_id, SEXP R_index, SEXP R_name, SEXP R_size);
+/* H5_DLL ssize_t H5Pget_virtual_filename(hid_t dcpl_id, size_t index, char *name, size_t size); */
+SEXP R_H5Pget_virtual_filename(SEXP R_dcpl_id, SEXP R_index, SEXP R_name, SEXP R_size);
+/* H5_DLL herr_t H5Pget_virtual_printf_gap(hid_t plist_id, hsize_t *gap_size); */
+SEXP R_H5Pget_virtual_printf_gap(SEXP R_plist_id, SEXP R_gap_size);
+/* H5_DLL hid_t H5Pget_virtual_srcspace(hid_t dcpl_id, size_t index); */
+SEXP R_H5Pget_virtual_srcspace(SEXP R_dcpl_id, SEXP R_index);
+/* H5_DLL herr_t H5Pget_virtual_view(hid_t plist_id, H5D_vds_view_t *view); */
+SEXP R_H5Pget_virtual_view(SEXP R_plist_id, SEXP R_view);
+/* H5_DLL hid_t H5Pget_virtual_vspace(hid_t dcpl_id, size_t index); */
+SEXP R_H5Pget_virtual_vspace(SEXP R_dcpl_id, SEXP R_index);
 /* H5_DLL htri_t H5Pisa_class(hid_t plist_id, hid_t pclass_id); */
 SEXP R_H5Pisa_class(SEXP R_plist_id, SEXP R_pclass_id);
 /* H5_DLL herr_t H5Pmodify_filter(hid_t plist_id, H5Z_filter_t filter, unsigned int flags, size_t cd_nelmts, const unsigned int cd_values[]); */
@@ -167,8 +197,12 @@ SEXP R_H5Pset_char_encoding(SEXP R_plist_id, SEXP R_encoding);
 SEXP R_H5Pset_chunk(SEXP R_plist_id, SEXP R_ndims, SEXP R_dim);
 /* H5_DLL herr_t H5Pset_chunk_cache(hid_t dapl_id, size_t rdcc_nslots, size_t rdcc_nbytes, double rdcc_w0); */
 SEXP R_H5Pset_chunk_cache(SEXP R_dapl_id, SEXP R_rdcc_nslots, SEXP R_rdcc_nbytes, SEXP R_rdcc_w0);
+/* H5_DLL herr_t H5Pset_chunk_opts(hid_t plist_id, unsigned opts); */
+SEXP R_H5Pset_chunk_opts(SEXP R_plist_id, SEXP R_opts);
 /* H5_DLL herr_t H5Pset_copy_object(hid_t plist_id, unsigned crt_intmd); */
 SEXP R_H5Pset_copy_object(SEXP R_plist_id, SEXP R_crt_intmd);
+/* H5_DLL herr_t H5Pset_core_write_tracking(hid_t fapl_id, hbool_t is_enabled, size_t page_size); */
+SEXP R_H5Pset_core_write_tracking(SEXP R_fapl_id, SEXP R_is_enabled, SEXP R_page_size);
 /* H5_DLL herr_t H5Pset_create_intermediate_group(hid_t plist_id, unsigned crt_intmd); */
 SEXP R_H5Pset_create_intermediate_group(SEXP R_plist_id, SEXP R_crt_intmd);
 /* H5_DLL herr_t H5Pset_data_transform(hid_t plist_id, const char* expression); */
@@ -179,6 +213,8 @@ SEXP R_H5Pset_deflate(SEXP R_plist_id, SEXP R_aggression);
 SEXP R_H5Pset_driver(SEXP R_plist_id, SEXP R_driver_id, SEXP R_driver_info);
 /* H5_DLL herr_t H5Pset_edc_check(hid_t plist_id, H5Z_EDC_t check); */
 SEXP R_H5Pset_edc_check(SEXP R_plist_id, SEXP R_check);
+/* H5_DLL herr_t H5Pset_efile_prefix(hid_t dapl_id, const char* prefix); */
+SEXP R_H5Pset_efile_prefix(SEXP R_dapl_id, SEXP R_prefix);
 /* H5_DLL herr_t H5Pset_elink_acc_flags(hid_t lapl_id, unsigned flags); */
 SEXP R_H5Pset_elink_acc_flags(SEXP R_lapl_id, SEXP R_flags);
 /* H5_DLL herr_t H5Pset_elink_fapl(hid_t lapl_id, hid_t fapl_id); */
@@ -197,6 +233,8 @@ SEXP R_H5Pset_family_offset(SEXP R_fapl_id, SEXP R_offset);
 SEXP R_H5Pset_fclose_degree(SEXP R_fapl_id, SEXP R_degree);
 /* H5_DLL herr_t H5Pset_file_image(hid_t fapl_id, void *buf_ptr, size_t buf_len); */
 SEXP R_H5Pset_file_image(SEXP R_fapl_id, SEXP R_buf_ptr, SEXP R_buf_len, SEXP _dupl_buf_ptr);
+/* H5_DLL herr_t H5Pset_file_space(hid_t plist_id, H5F_file_space_type_t strategy, hsize_t threshold); */
+SEXP R_H5Pset_file_space(SEXP R_plist_id, SEXP R_strategy, SEXP R_threshold);
 /* H5_DLL herr_t H5Pset_fill_time(hid_t plist_id, H5D_fill_time_t fill_time); */
 SEXP R_H5Pset_fill_time(SEXP R_plist_id, SEXP R_fill_time);
 /* H5_DLL herr_t H5Pset_fill_value(hid_t plist_id, hid_t type_id, const void *value); */
@@ -223,8 +261,12 @@ SEXP R_H5Pset_link_phase_change(SEXP R_plist_id, SEXP R_max_compact, SEXP R_min_
 SEXP R_H5Pset_local_heap_size_hint(SEXP R_plist_id, SEXP R_size_hint);
 /* H5_DLL herr_t H5Pset_mdc_config(hid_t plist_id, H5AC_cache_config_t * config_ptr); */
 SEXP R_H5Pset_mdc_config(SEXP R_plist_id, SEXP R_config_ptr);
+/* H5_DLL herr_t H5Pset_mdc_log_options(hid_t plist_id, hbool_t is_enabled, const char *location, hbool_t start_on_access); */
+SEXP R_H5Pset_mdc_log_options(SEXP R_plist_id, SEXP R_is_enabled, SEXP R_location, SEXP R_start_on_access);
 /* H5_DLL herr_t H5Pset_meta_block_size(hid_t fapl_id, hsize_t size); */
 SEXP R_H5Pset_meta_block_size(SEXP R_fapl_id, SEXP R_size);
+/* H5_DLL herr_t H5Pset_metadata_read_attempts(hid_t plist_id, unsigned attempts); */
+SEXP R_H5Pset_metadata_read_attempts(SEXP R_plist_id, SEXP R_attempts);
 /* H5_DLL herr_t H5Pset_multi_type(hid_t fapl_id, H5FD_mem_t type); */
 SEXP R_H5Pset_multi_type(SEXP R_fapl_id, SEXP R_type);
 /* H5_DLL herr_t H5Pset_nbit(hid_t plist_id); */
@@ -257,6 +299,12 @@ SEXP R_H5Pset_sym_k(SEXP R_plist_id, SEXP R_ik, SEXP R_lk);
 SEXP R_H5Pset_szip(SEXP R_plist_id, SEXP R_options_mask, SEXP R_pixels_per_block);
 /* H5_DLL herr_t H5Pset_userblock(hid_t plist_id, hsize_t size); */
 SEXP R_H5Pset_userblock(SEXP R_plist_id, SEXP R_size);
+/* H5_DLL herr_t H5Pset_virtual(hid_t dcpl_id, hid_t vspace_id, const char *src_file_name, const char *src_dset_name, hid_t src_space_id); */
+SEXP R_H5Pset_virtual(SEXP R_dcpl_id, SEXP R_vspace_id, SEXP R_src_file_name, SEXP R_src_dset_name, SEXP R_src_space_id);
+/* H5_DLL herr_t H5Pset_virtual_printf_gap(hid_t plist_id, hsize_t gap_size); */
+SEXP R_H5Pset_virtual_printf_gap(SEXP R_plist_id, SEXP R_gap_size);
+/* H5_DLL herr_t H5Pset_virtual_view(hid_t plist_id, H5D_vds_view_t view); */
+SEXP R_H5Pset_virtual_view(SEXP R_plist_id, SEXP R_view);
 /* H5_DLL herr_t H5Punregister(hid_t pclass_id, const char *name); */
 SEXP R_H5Punregister(SEXP R_pclass_id, SEXP R_name);
 #endif
