@@ -496,6 +496,26 @@ SEXP R_H5Tequal(SEXP R_type1_id, SEXP R_type2_id){
   return(__ret_list);
 }
 
+/* H5_DLL herr_t H5Tflush(hid_t type_id); */
+SEXP R_H5Tflush(SEXP R_type_id){
+  int vars_protected=0;
+  hid_t type_id = SEXP_to_longlong(R_type_id, 0);
+  herr_t return_val = H5Tflush(type_id);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
 /* H5_DLL int H5Tget_array_dims2(hid_t type_id, hsize_t dims[]); */
 SEXP R_H5Tget_array_dims2(SEXP R_type_id, SEXP R_dims){
   hsize_t size_helper;
@@ -1289,6 +1309,26 @@ SEXP R_H5Tpack(SEXP R_type_id){
   return(__ret_list);
 }
 
+/* H5_DLL herr_t H5Trefresh(hid_t type_id); */
+SEXP R_H5Trefresh(SEXP R_type_id){
+  int vars_protected=0;
+  hid_t type_id = SEXP_to_longlong(R_type_id, 0);
+  herr_t return_val = H5Trefresh(type_id);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
 /* H5_DLL herr_t H5Tset_cset(hid_t type_id, H5T_cset_t cset); */
 SEXP R_H5Tset_cset(SEXP R_type_id, SEXP R_cset){
   int vars_protected=0;
