@@ -7,6 +7,8 @@ SEXP R_H5check_version(SEXP R_majnum, SEXP R_minnum, SEXP R_relnum);
 SEXP R_H5close(void);
 /* H5_DLL herr_t H5dont_atexit(void); */
 SEXP R_H5dont_atexit(void);
+/* H5_DLL herr_t H5free_memory(void *mem); */
+SEXP R_H5free_memory(SEXP R_mem, SEXP _dupl_mem);
 /* H5_DLL herr_t H5garbage_collect(void); */
 SEXP R_H5garbage_collect(void);
 /* H5_DLL herr_t H5get_libversion(unsigned *majnum, unsigned *minnum, unsigned *relnum); */
